"""
HADEX - Hadal Abyss Dynamics & Extreme-Pressure Intelligence
A Physics-Based Framework for Ultra-Deep Ocean Exploration
"""

__version__ = "1.0.0"
__author__ = "Samir Baladi"
__email__ = "gitdeeper@gmail.com"
__license__ = "Open Source"
__doi__ = "10.5281/zenodo.18883858"
